@@ -47,7 +47,9 @@ describe 'keystone::resource::authtoken' do
         is_expected.to contain_keystone_config('keystone_authtoken/region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/service_token_roles').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/service_token_roles_required').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('keystone_authtoken/service_type').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('keystone_authtoken/interface').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -78,7 +80,9 @@ describe 'keystone::resource::authtoken' do
           :region_name                  => 'MyRegion',
           :service_token_roles          => 'service',
           :service_token_roles_required => false,
+          :service_type                 => 'identity',
           :token_cache_time             => '20',
+          :interface                    => 'internal',
         })
       end
       it 'override keystone authtoken parameters' do
@@ -93,12 +97,15 @@ describe 'keystone::resource::authtoken' do
         is_expected.to contain_keystone_config('keystone_authtoken/www_authenticate_uri').with_value(params[:www_authenticate_uri])
         is_expected.to contain_keystone_config('keystone_authtoken/auth_version').with_value(params[:auth_version])
         is_expected.to contain_keystone_config('keystone_authtoken/cache').with_value(params[:cache])
+        is_expected.to contain_keystone_config('keystone_authtoken/cafile').with_value(params[:cafile])
+        is_expected.to contain_keystone_config('keystone_authtoken/certfile').with_value(params[:certfile])
         is_expected.to contain_keystone_config('keystone_authtoken/collect_timing').with_value(params[:collect_timing])
         is_expected.to contain_keystone_config('keystone_authtoken/delay_auth_decision').with_value(params[:delay_auth_decision])
         is_expected.to contain_keystone_config('keystone_authtoken/enforce_token_bind').with_value(params[:enforce_token_bind])
         is_expected.to contain_keystone_config('keystone_authtoken/http_connect_timeout').with_value(params[:http_connect_timeout])
         is_expected.to contain_keystone_config('keystone_authtoken/http_request_max_retries').with_value(params[:http_request_max_retries])
         is_expected.to contain_keystone_config('keystone_authtoken/include_service_catalog').with_value(params[:include_service_catalog])
+        is_expected.to contain_keystone_config('keystone_authtoken/keyfile').with_value(params[:keyfile])
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_pool_conn_get_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_pool_dead_retry').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_pool_maxsize').with_value('<SERVICE DEFAULT>')
@@ -111,7 +118,9 @@ describe 'keystone::resource::authtoken' do
         is_expected.to contain_keystone_config('keystone_authtoken/region_name').with_value(params[:region_name])
         is_expected.to contain_keystone_config('keystone_authtoken/service_token_roles').with_value(params[:service_token_roles])
         is_expected.to contain_keystone_config('keystone_authtoken/service_token_roles_required').with_value(params[:service_token_roles_required])
+        is_expected.to contain_keystone_config('keystone_authtoken/service_type').with_value(params[:service_type])
         is_expected.to contain_keystone_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
+        is_expected.to contain_keystone_config('keystone_authtoken/interface').with_value(params[:interface])
       end
     end
 
@@ -205,7 +214,7 @@ describe 'keystone::resource::authtoken' do
         when 'Debian'
           memcache_package_name = 'python3-memcache'
         when 'RedHat'
-          memcache_package_name = 'python-memcached'
+          memcache_package_name = 'python3-memcached'
         end
         {
           :memcache_package_name => memcache_package_name
